const disabled = true
const docRoot = 'https://docs.aws.amazon.com/sns/latest/api/'
export default {
  AddPermission:                      { disabled, awsDoc: docRoot + 'API_AddPermission.html' },
  CheckIfPhoneNumberIsOptedOut:       { disabled, awsDoc: docRoot + 'API_CheckIfPhoneNumberIsOptedOut.html' },
  ConfirmSubscription:                { disabled, awsDoc: docRoot + 'API_ConfirmSubscription.html' },
  CreatePlatformApplication:          { disabled, awsDoc: docRoot + 'API_CreatePlatformApplication.html' },
  CreatePlatformEndpoint:             { disabled, awsDoc: docRoot + 'API_CreatePlatformEndpoint.html' },
  CreateSMSSandboxPhoneNumber:        { disabled, awsDoc: docRoot + 'API_CreateSMSSandboxPhoneNumber.html' },
  CreateTopic:                        { disabled, awsDoc: docRoot + 'API_CreateTopic.html' },
  DeleteEndpoint:                     { disabled, awsDoc: docRoot + 'API_DeleteEndpoint.html' },
  DeletePlatformApplication:          { disabled, awsDoc: docRoot + 'API_DeletePlatformApplication.html' },
  DeleteSMSSandboxPhoneNumber:        { disabled, awsDoc: docRoot + 'API_DeleteSMSSandboxPhoneNumber.html' },
  DeleteTopic:                        { disabled, awsDoc: docRoot + 'API_DeleteTopic.html' },
  GetDataProtectionPolicy:            { disabled, awsDoc: docRoot + 'API_GetDataProtectionPolicy.html' },
  GetEndpointAttributes:              { disabled, awsDoc: docRoot + 'API_GetEndpointAttributes.html' },
  GetPlatformApplicationAttributes:   { disabled, awsDoc: docRoot + 'API_GetPlatformApplicationAttributes.html' },
  GetSMSAttributes:                   { disabled, awsDoc: docRoot + 'API_GetSMSAttributes.html' },
  GetSMSSandboxAccountStatus:         { disabled, awsDoc: docRoot + 'API_GetSMSSandboxAccountStatus.html' },
  GetSubscriptionAttributes:          { disabled, awsDoc: docRoot + 'API_GetSubscriptionAttributes.html' },
  GetTopicAttributes:                 { disabled, awsDoc: docRoot + 'API_GetTopicAttributes.html' },
  ListEndpointsByPlatformApplication: { disabled, awsDoc: docRoot + 'API_ListEndpointsByPlatformApplication.html' },
  ListOriginationNumbers:             { disabled, awsDoc: docRoot + 'API_ListOriginationNumbers.html' },
  ListPhoneNumbersOptedOut:           { disabled, awsDoc: docRoot + 'API_ListPhoneNumbersOptedOut.html' },
  ListPlatformApplications:           { disabled, awsDoc: docRoot + 'API_ListPlatformApplications.html' },
  ListSMSSandboxPhoneNumbers:         { disabled, awsDoc: docRoot + 'API_ListSMSSandboxPhoneNumbers.html' },
  ListSubscriptions:                  { disabled, awsDoc: docRoot + 'API_ListSubscriptions.html' },
  ListSubscriptionsByTopic:           { disabled, awsDoc: docRoot + 'API_ListSubscriptionsByTopic.html' },
  ListTagsForResource:                { disabled, awsDoc: docRoot + 'API_ListTagsForResource.html' },
  ListTopics:                         { disabled, awsDoc: docRoot + 'API_ListTopics.html' },
  OptInPhoneNumber:                   { disabled, awsDoc: docRoot + 'API_OptInPhoneNumber.html' },
  PublishBatch:                       { disabled, awsDoc: docRoot + 'API_PublishBatch.html' },
  PutDataProtectionPolicy:            { disabled, awsDoc: docRoot + 'API_PutDataProtectionPolicy.html' },
  RemovePermission:                   { disabled, awsDoc: docRoot + 'API_RemovePermission.html' },
  SetEndpointAttributes:              { disabled, awsDoc: docRoot + 'API_SetEndpointAttributes.html' },
  SetPlatformApplicationAttributes:   { disabled, awsDoc: docRoot + 'API_SetPlatformApplicationAttributes.html' },
  SetSMSAttributes:                   { disabled, awsDoc: docRoot + 'API_SetSMSAttributes.html' },
  SetSubscriptionAttributes:          { disabled, awsDoc: docRoot + 'API_SetSubscriptionAttributes.html' },
  SetTopicAttributes:                 { disabled, awsDoc: docRoot + 'API_SetTopicAttributes.html' },
  Subscribe:                          { disabled, awsDoc: docRoot + 'API_Subscribe.html' },
  TagResource:                        { disabled, awsDoc: docRoot + 'API_TagResource.html' },
  Unsubscribe:                        { disabled, awsDoc: docRoot + 'API_Unsubscribe.html' },
  UntagResource:                      { disabled, awsDoc: docRoot + 'API_UntagResource.html' },
  VerifySMSSandboxPhoneNumber:        { disabled, awsDoc: docRoot + 'API_VerifySMSSandboxPhoneNumber.html' },
}
